@@ -286,6 +286,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -335,6 +337,9 @@ class CloudWatchLogsAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchLogsAction.__init__)
+            check_type(argname="argument log_group", value=log_group, expected_type=type_hints["log_group"])
         props = CloudWatchLogsActionProps(role=role)
 
         jsii.create(self.__class__, self, [log_group, props])
@@ -347,6 +352,9 @@ class CloudWatchLogsAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchLogsAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -415,6 +423,9 @@ class CloudWatchPutMetricAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchPutMetricAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -472,6 +483,9 @@ class CloudWatchSetAlarmStateAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateAction.__init__)
+            check_type(argname="argument alarm", value=alarm, expected_type=type_hints["alarm"])
         props = CloudWatchSetAlarmStateActionProps(
             alarm_state_to_set=alarm_state_to_set, reason=reason, role=role
         )
@@ -489,6 +503,9 @@ class CloudWatchSetAlarmStateAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateAction.bind)
+            check_type(argname="argument topic_rule", value=topic_rule, expected_type=type_hints["topic_rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [topic_rule]))
 
 
@@ -519,6 +536,9 @@ class CommonActionProps:
                 role=role
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CommonActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -594,6 +614,9 @@ class FirehosePutRecordAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FirehosePutRecordAction.__init__)
+            check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = FirehosePutRecordActionProps(
             batch_mode=batch_mode, record_separator=record_separator, role=role
         )
@@ -608,6 +631,9 @@ class FirehosePutRecordAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FirehosePutRecordAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -658,6 +684,11 @@ class FirehosePutRecordActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FirehosePutRecordActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument batch_mode", value=batch_mode, expected_type=type_hints["batch_mode"])
+            check_type(argname="argument record_separator", value=record_separator, expected_type=type_hints["record_separator"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -802,6 +833,9 @@ class IotRepublishMqttAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IotRepublishMqttAction.__init__)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         props = IotRepublishMqttActionProps(
             quality_of_service=quality_of_service, role=role
         )
@@ -816,6 +850,9 @@ class IotRepublishMqttAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IotRepublishMqttAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -850,6 +887,10 @@ class IotRepublishMqttActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IotRepublishMqttActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument quality_of_service", value=quality_of_service, expected_type=type_hints["quality_of_service"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -932,6 +973,9 @@ class KinesisPutRecordAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisPutRecordAction.__init__)
+            check_type(argname="argument stream", value=stream, expected_type=type_hints["stream"])
         props = KinesisPutRecordActionProps(partition_key=partition_key, role=role)
 
         jsii.create(self.__class__, self, [stream, props])
@@ -944,6 +988,9 @@ class KinesisPutRecordAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisPutRecordAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -983,6 +1030,10 @@ class KinesisPutRecordActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisPutRecordActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument partition_key", value=partition_key, expected_type=type_hints["partition_key"])
         self._values: typing.Dict[str, typing.Any] = {
             "partition_key": partition_key,
         }
@@ -1058,6 +1109,9 @@ class LambdaFunctionAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaFunctionAction.__init__)
+            check_type(argname="argument func", value=func, expected_type=type_hints["func"])
         jsii.create(self.__class__, self, [func])
 
     @jsii.member(jsii_name="bind")
@@ -1071,6 +1125,9 @@ class LambdaFunctionAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaFunctionAction.bind)
+            check_type(argname="argument topic_rule", value=topic_rule, expected_type=type_hints["topic_rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [topic_rule]))
 
 
@@ -1152,6 +1209,9 @@ class S3PutObjectAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3PutObjectAction.__init__)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
         props = S3PutObjectActionProps(
             access_control=access_control, key=key, role=role
         )
@@ -1166,6 +1226,9 @@ class S3PutObjectAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3PutObjectAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -1204,6 +1267,11 @@ class S3PutObjectActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3PutObjectActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -1339,6 +1407,9 @@ class SnsTopicAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsTopicAction.__init__)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         props = SnsTopicActionProps(message_format=message_format, role=role)
 
         jsii.create(self.__class__, self, [topic, props])
@@ -1351,6 +1422,9 @@ class SnsTopicAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsTopicAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -1390,6 +1464,10 @@ class SnsTopicActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsTopicActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument message_format", value=message_format, expected_type=type_hints["message_format"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -1474,6 +1552,9 @@ class SqsQueueAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsQueueAction.__init__)
+            check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         props = SqsQueueActionProps(use_base64=use_base64, role=role)
 
         jsii.create(self.__class__, self, [queue, props])
@@ -1486,6 +1567,9 @@ class SqsQueueAction(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsQueueAction.bind)
+            check_type(argname="argument rule", value=rule, expected_type=type_hints["rule"])
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
 
 
@@ -1525,6 +1609,10 @@ class SqsQueueActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsQueueActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument use_base64", value=use_base64, expected_type=type_hints["use_base64"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -1592,6 +1680,9 @@ class CloudWatchLogsActionProps(CommonActionProps):
                 role=role
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchLogsActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {}
         if role is not None:
             self._values["role"] = role
@@ -1669,6 +1760,14 @@ class CloudWatchPutMetricActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchPutMetricActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument metric_name", value=metric_name, expected_type=type_hints["metric_name"])
+            check_type(argname="argument metric_namespace", value=metric_namespace, expected_type=type_hints["metric_namespace"])
+            check_type(argname="argument metric_unit", value=metric_unit, expected_type=type_hints["metric_unit"])
+            check_type(argname="argument metric_value", value=metric_value, expected_type=type_hints["metric_value"])
+            check_type(argname="argument metric_timestamp", value=metric_timestamp, expected_type=type_hints["metric_timestamp"])
         self._values: typing.Dict[str, typing.Any] = {
             "metric_name": metric_name,
             "metric_namespace": metric_namespace,
@@ -1822,6 +1921,11 @@ class CloudWatchSetAlarmStateActionProps(CommonActionProps):
                 ]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloudWatchSetAlarmStateActionProps.__init__)
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument alarm_state_to_set", value=alarm_state_to_set, expected_type=type_hints["alarm_state_to_set"])
+            check_type(argname="argument reason", value=reason, expected_type=type_hints["reason"])
         self._values: typing.Dict[str, typing.Any] = {
             "alarm_state_to_set": alarm_state_to_set,
         }
